hotspot/src/share/vm/runtime/arguments.cpp
changeset 38195 d317aafcc87c
parent 38151 fffedc5e5cf8
child 38207 2ed792c9481d
--- a/hotspot/src/share/vm/runtime/arguments.cpp	Wed May 04 23:45:10 2016 +0000
+++ b/hotspot/src/share/vm/runtime/arguments.cpp	Wed May 04 21:53:01 2016 -0400
@@ -778,8 +778,8 @@
   return path;
 }
 
-// Parses a memory size specification string.
-static bool atomull(const char *s, julong* result) {
+// Parses a size specification string.
+bool Arguments::atojulong(const char *s, julong* result) {
   julong n = 0;
   int args_read = 0;
   bool is_hex = false;
@@ -885,7 +885,7 @@
     return false;
   }
 
   // Check the sign first since atomull() parses only unsigned values.
   if (*value == '-') {
     if (!result->is_intx() && !result->is_int()) {
       return false;
@@ -893,7 +893,7 @@
     value++;
     is_neg = true;
   }
-  if (!atomull(value, &v)) {
+  if (!Arguments::atojulong(value, &v)) {
     return false;
   }
   if (result->is_int()) {
@@ -2693,12 +2693,12 @@
                             uintx* uintx_arg,
                             uintx min_size) {
 
   // Check the sign first since atomull() parses only unsigned values.
   bool value_is_positive = !(*value == '-');
 
   if (value_is_positive) {
     julong n;
-    bool good_return = atomull(value, &n);
+    bool good_return = atojulong(value, &n);
     if (good_return) {
       bool above_minimum = n >= min_size;
       bool value_is_too_large = n > max_uintx;
@@ -2715,7 +2715,7 @@
 Arguments::ArgsRange Arguments::parse_memory_size(const char* s,
                                                   julong* long_arg,
                                                   julong min_size) {
-  if (!atomull(s, long_arg)) return arg_unreadable;
+  if (!atojulong(s, long_arg)) return arg_unreadable;
   return check_memory_size(*long_arg, min_size);
 }
@@ -885,7 +885,7 @@
   }
 
-  // Check the sign first since atomull() parses only unsigned values.
+  // Check the sign first since atojulong() parses only unsigned values.
   if (*value == '-') {
     if (!result->is_intx() && !result->is_int()) {
@@ -2693,12 +2693,12 @@
                             uintx min_size) {
 
-  // Check the sign first since atomull() parses only unsigned values.
+  // Check the sign first since atojulong() parses only unsigned values.
   bool value_is_positive = !(*value == '-');
 